@@ -32,6 +32,8 @@ games_list_supported_all() {
 	available_threads=$(nproc)
 	## Passing the --list-supported-games switch is not required,
 	## because $PLAYIT_OPTION_LIST_SUPPORTED_GAMES is already set.
+	unset PLAYIT_COMPATIBILITY_LEVEL
+	unset target_version
 	printf '%s' "$scripts_list" |
 		xargs --delimiter='\n' --max-args=1 --max-procs="$available_threads" sh |
 		sort --unique
