@@ -26,9 +26,9 @@ requirements_list() {
 
 	# If a WINE init .reg script is to be generated,
 	# ensure that iconv is available
-	local wine_registry_script_content
-	wine_registry_script_content=$(wine_registry_script_content)
-	if [ -n "$wine_registry_script_content" ]; then
+	local regedit_initial_content
+	regedit_initial_content=$(regedit_initial_content)
+	if [ -n "$regedit_initial_content" ]; then
 		requirements_list="$requirements_list
 		iconv"
 	fi
@@ -76,8 +76,7 @@ requirements_list_package() {
 			requirements='dpkg-deb'
 		;;
 		('gentoo')
-			# fakeroot-ng doesn't work anymore, fakeroot >=1.25.1 does
-			requirements='fakeroot ebuild'
+			requirements='tar bzip2'
 		;;
 	esac
 
