@@ -41,6 +41,11 @@ requirements_check_dpkg_deb_version() {
 		LC_ALL=C dpkg-deb --version |
 			sed --silent "s/Debian 'dpkg-deb' package archive backend version \\([\\.0-9]\\+\\) (amd64)\\./\\1/p"
 	)
+	## Throw an explicit error if current dpkg-deb version could not be fetched.
+	if [ -z "$version_available" ]; then
+		error_dpkg_version_not_found
+		return 1
+	fi
 	## The required option --root-owner-group is only available with dpkg-deb ≥ 1.19.0.
 	version_required='1.19.0'
 
