@@ -47,6 +47,7 @@ application_type() {
 			'native' | \
 			'renpy' | \
 			'scummvm' | \
+			'web' | \
 			'wine' \
 		)
 			## This is a supported type, no error to throw.
@@ -110,6 +111,9 @@ application_type_guess_from_file() {
 		)
 			application_type='native'
 		;;
+		('text/html')
+			application_type='web'
+		;;
 		( \
 			'application/x-dosexec' | \
 			'application/vnd.microsoft.portable-executable' \
