@@ -125,74 +125,58 @@ archive_size() {
 	printf '%s' "$archive_size"
 }
 
-# Get the expected MD5 hash of a given archive.
-# This can be an empty value.
-# USAGE: archive_hash_md5 $archive
-archive_hash_md5() {
+# Get the list of valid MD5 hashes for a given archive.
+# This list can be empty.
+# USAGE: archive_hashes_list_md5 $archive
+archive_hashes_list_md5() {
 	local archive
 	archive="$1"
 
-	## TODO: In addition to a single hash or an empty string,
-	##       this function should be able to return a list of hashes.
-	##       The candidate archive would be considered valid if its computed hash
-	##       matches any of the hashes returned by the current function.
+	local hashes_list
+	hashes_list=$(get_value "${archive}_MD5")
 
-	get_value "${archive}_MD5"
+	printf '%s' "$hashes_list" | list_clean
 }
 
 # Get the computed MD5 hash of a given archive.
-# If a value is already stored in cache, this value is fetched;
-# otherwise the hash is computed, then stored in cache.
-# USAGE: archive_hash_md5_computed $archive
+# If a value is already stored in cache, this value is fetched; otherwise the hash is computed, then stored in cache.
+# The cache is stored in a file instead of a variable, as this function is usually called from a subshell.
+# USAGE: archive_hash_md5_computed $archive_name
 archive_hash_md5_computed() {
-	## TODO: The archive file name should be used instead of its identifier.
-	local archive
-	archive="$1"
-
-	# Ensure that a value from the global scope
-	# can not leak into the current function call.
-	local archive_hash_computed
-	archive_hash_computed=''
+	## A file name, found in the same directory than the main archive.
+	local archive_name
+	archive_name="$1"
 
 	# If the hash has already been computed, use the cached value.
-	## We can not use a global variable here, because the current function can be called from a subshell.
+	local hash_md5_computed=''
 	if [ -n "${PLAYIT_WORKDIR:-}" ]; then
 		local cache_directory cache_file_hashes
 		cache_directory="${PLAYIT_WORKDIR}/cache"
 		cache_file_hashes="${cache_directory}/hashes"
 		if [ -f "$cache_file_hashes" ]; then
-			archive_hash_computed=$(sed --silent "s/^${archive} | \([0-9a-f]\{32\}\)$/\1/p" "$cache_file_hashes")
-			## If the current archive is the main archive, its hash might have already been cached under another name.
-			if [ -z "$archive_hash_computed" ] && [ "$archive" != 'SOURCE_ARCHIVE' ]; then
-				archive_name_main=$(archive_name 'SOURCE_ARCHIVE')
-				archive_name_current=$(archive_name "$archive")
-				if [ "$archive_name_main" = "$archive_name_current" ]; then
-					archive_hash_computed=$(sed --silent "s/^SOURCE_ARCHIVE | \([0-9a-f]\{32\}\)$/\1/p" "$cache_file_hashes")
-				fi
-			fi
+			hash_md5_computed=$(sed --silent --expression="s/^${archive_name} | \([0-9a-f]\{32\}\)$/\1/p" "$cache_file_hashes")
 		fi
 	fi
 
 	# If no cached value has been found, compute the hash.
-	if [ -z "$archive_hash_computed" ]; then
-		local archive_name archive_path
-		archive_name=$(archive_name "$archive")
-		archive_path=$(archive_path "$archive")
+	if [ -z "$hash_md5_computed" ]; then
+		local archives_path_base archive_path
+		archives_path_base=$(archives_path_base)
+		archive_path="${archives_path_base}/${archive_name}"
 		## Print the message to the error output, to prevent messing up with the current function output.
 		info_archive_hash_computation "$archive_name" >/dev/stderr
-		archive_hash_computed=$(md5sum "$archive_path" | awk '{print $1}')
+		hash_md5_computed=$(md5sum "$archive_path" | awk '{print $1}')
 
 		# Cache the hash to prevent computing it again.
-		## We can not use a global variable here, because the current function can be called from a subshell.
 		if [ -n "${PLAYIT_WORKDIR:-}" ]; then
 			mkdir --parents "$cache_directory"
 			cat >> "$cache_file_hashes" <<- EOF
-			$archive | $archive_hash_computed
+			$archive_name | $hash_md5_computed
 			EOF
 		fi
 	fi
 
-	printf '%s' "$archive_hash_computed"
+	printf '%s' "$hash_md5_computed"
 }
 
 # Get the type of a given archive
