@@ -24,13 +24,11 @@ archive_extraction_appimage() {
 	local archive_offset
 	archive_offset=$(binwalk "$archive_path" | sed --silent 's/\(^[0-9]\+\).*Squashfs filesystem.*/\1/p')
 
-	local archive_extraction_return_code
-	{
+	if ! {
 		printf 'unsquashfs -offset "%s" -dest "%s" "%s"\n' "$archive_offset" "$destination_directory" "$archive_path"
 		unsquashfs -offset "$archive_offset" -dest "$destination_directory" "$archive_path"
-		archive_extraction_return_code=$?
-	} >> "$log_file" || true
-	if [ $archive_extraction_return_code -ne 0 ]; then
+	} >> "$log_file"
+	then
 		error_archive_extraction_failure "$archive"
 		return 1
 	fi
