@@ -26,7 +26,10 @@ content_inclusion_wineprefix_tweaks_mono() {
 	local mono_installer_source package_path path_game_data mono_installer_name mono_installer_destination
 	mono_installer_source=$(archive_path 'ARCHIVE_MONO')
 	package_path=$(package_path "$package")
-	path_game_data=$(path_game_data)
+	path_game_data=$(
+		set_current_package "$package"
+		path_game_data
+	)
 	mono_installer_name=$(archive_name 'ARCHIVE_MONO')
 	mono_installer_destination="${package_path}${path_game_data}/wineprefix-tweaks/${mono_installer_name}"
 	install -D --mode=644 "$mono_installer_source" "$mono_installer_destination"
