@@ -41,21 +41,19 @@ information_installation_instructions_variant() {
 # Display a list of unknown runtime commands from packages dependencies
 # USAGE: warning_dependencies_unknown_commands
 warning_dependencies_unknown_commands() {
-	local messages_language message1 message2
+	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
 		('fr')
-			message1='Certaines dépendances de ce jeu ne sont pas encore prises en charge par ./play.it'
-			message1="$message1"', voici la liste de celles qui ont été ignorées :\n'
-			message2='Merci de signaler cette liste sur notre système de suivi :\n%s\n'
+			message='Certaines dépendances de ce jeu ne sont pas encore prises en charge par ./play.it'
+			message="$message"', voici la liste de celles qui ont été ignorées :\n'
 		;;
 		('en'|*)
-			message1='Some dependencies of this game are not supported by ./play.it yet'
-			message1="$message1"', here are the ones that have been skipped:\n'
-			message2='Please report this list on our issues tracker:\n%s\n'
+			message='Some dependencies of this game are not supported by ./play.it yet'
+			message="$message"', here are the ones that have been skipped:\n'
 		;;
 	esac
-	print_message 'warning' "$message1"
+	print_message 'warning' "$message"
 	local unknown_command
 	while read -r unknown_command; do
 		print_message 'info' '- %s\n' \
@@ -63,28 +61,24 @@ warning_dependencies_unknown_commands() {
 	done <<- EOL
 	$(dependencies_unknown_commands_list)
 	EOL
-	print_message 'info' "$message2" \
-		"$PLAYIT_BUG_TRACKER_URL"
 }
 
 # Display a list of unknown libraries from packages dependencies
 # USAGE: warning_dependencies_unknown_libraries
 warning_dependencies_unknown_libraries() {
-	local messages_language message1 message2
+	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
 		('fr')
-			message1='Certaines dépendances de ce jeu ne sont pas encore prises en charge par ./play.it'
-			message1="$message1"', voici la liste de celles qui ont été ignorées :\n'
-			message2='Merci de signaler cette liste sur notre système de suivi :\n%s\n'
+			message='Certaines dépendances de ce jeu ne sont pas encore prises en charge par ./play.it'
+			message="$message"', voici la liste de celles qui ont été ignorées :\n'
 		;;
 		('en'|*)
-			message1='Some dependencies of this game are not supported by ./play.it yet'
-			message1="$message1"', here are the ones that have been skipped:\n'
-			message2='Please report this list on our issues tracker:\n%s\n'
+			message='Some dependencies of this game are not supported by ./play.it yet'
+			message="$message"', here are the ones that have been skipped:\n'
 		;;
 	esac
-	print_message 'warning' "$message1"
+	print_message 'warning' "$message"
 	local unkown_library
 	while read -r unkown_library; do
 		print_message 'info' '- %s\n' \
@@ -92,28 +86,24 @@ warning_dependencies_unknown_libraries() {
 	done <<- EOL
 	$(dependencies_unknown_libraries_list)
 	EOL
-	print_message 'info' "$message2" \
-		"$PLAYIT_BUG_TRACKER_URL"
 }
 
 # Display a list of unknown Mono libraries from packages dependencies
 # USAGE: warning_dependencies_unknown_mono_libraries
 warning_dependencies_unknown_mono_libraries() {
-	local messages_language message1 message2
+	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
 		('fr')
-			message1='Certaines dépendances Mono de ce jeu ne sont pas encore prises en charge par ./play.it'
-			message1="$message1"', voici la liste de celles qui ont été ignorées :\n'
-			message2='Merci de signaler cette liste sur notre système de suivi :\n%s\n'
+			message='Certaines dépendances Mono de ce jeu ne sont pas encore prises en charge par ./play.it'
+			message="$message"', voici la liste de celles qui ont été ignorées :\n'
 		;;
 		('en'|*)
-			message1='Some Mono dependencies of this game are not supported by ./play.it yet'
-			message1="$message1"', here are the ones that have been skipped:\n'
-			message2='Please report this list on our issues tracker:\n%s\n'
+			message='Some Mono dependencies of this game are not supported by ./play.it yet'
+			message="$message"', here are the ones that have been skipped:\n'
 		;;
 	esac
-	print_message 'warning' "$message1"
+	print_message 'warning' "$message"
 	local unkown_mono_library
 	while read -r unkown_mono_library; do
 		print_message 'info' '- %s\n' \
@@ -121,28 +111,24 @@ warning_dependencies_unknown_mono_libraries() {
 	done <<- EOL
 	$(dependencies_unknown_mono_libraries_list)
 	EOL
-	print_message 'info' "$message2" \
-		"$PLAYIT_BUG_TRACKER_URL"
 }
 
 # Display a list of unknown GStreamer media formats from packages dependencies
 # USAGE: warning_dependencies_unknown_gstreamer_media_formats
 warning_dependencies_unknown_gstreamer_media_formats() {
-	local messages_language message1 message2
+	local messages_language message
 	messages_language=$(messages_language)
 	case "$messages_language" in
 		('fr')
-			message1='Certains formats multimédia requis par ce jeu ne sont pas encore pris en charge par ./play.it'
-			message1="$message1"', voici la liste de ceux qui ont été ignorés :\n'
-			message2='Merci de signaler cette liste sur notre système de suivi :\n%s\n'
+			message='Certains formats multimédia requis par ce jeu ne sont pas encore pris en charge par ./play.it'
+			message="$message"', voici la liste de ceux qui ont été ignorés :\n'
 		;;
 		('en'|*)
-			message1='Some media formats required by this game are not supported by ./play.it yet'
-			message1="$message1"', here are the ones that have been skipped:\n'
-			message2='Please report this list on our issues tracker:\n%s\n'
+			message='Some media formats required by this game are not supported by ./play.it yet'
+			message="$message"', here are the ones that have been skipped:\n'
 		;;
 	esac
-	print_message 'warning' "$message1"
+	print_message 'warning' "$message"
 	local media_format
 	while read -r media_format; do
 		print_message 'info' '- %s\n' \
@@ -150,7 +136,5 @@ warning_dependencies_unknown_gstreamer_media_formats() {
 	done <<- EOL
 	$(dependencies_unknown_gstreamer_media_formats_list)
 	EOL
-	print_message 'info' "$message2" \
-		"$PLAYIT_BUG_TRACKER_URL"
 }
 
