@@ -9,6 +9,19 @@ application_scummvm_scummid() {
 	local application_scummid
 	application_scummid=$(context_value "${application}_SCUMMID")
 
+	# If no explicit ScummVM id is set, try to guess one from the game engine
+	if [ -z "$application_scummid" ]; then
+		local game_engine
+		game_engine=$(game_engine)
+		case "$game_engine" in
+			('ags')
+				local ags_name
+				ags_name=$(ags_name)
+				application_scummid="ags:${ags_name}"
+			;;
+		esac
+	fi
+
 	# Return early if no ScummVM id is set
 	if [ -z "$application_scummid" ]; then
 		return 0
