@@ -13,7 +13,6 @@ scummvm_launcher() {
 			# Set the paths that should be available to the generated launcher
 			launcher_init_paths "$application"
 
-			scummvm_launcher_environment "$application"
 			scummvm_launcher_run
 			launcher_exit
 		;;
@@ -24,23 +23,6 @@ scummvm_launcher() {
 	esac
 }
 
-# ScummVM launcher - Set the environment
-# USAGE: scummvm_launcher_environment $application
-scummvm_launcher_environment() {
-	local application
-	application="$1"
-
-	local application_scummid
-	application_scummid=$(application_scummvm_scummid "$application")
-
-	cat <<- EOF
-	# Set the environment
-
-	SCUMMVM_ID='$application_scummid'
-
-	EOF
-}
-
 # ScummVM launcher - Run ScummVM
 # USAGE: scummvm_launcher_run
 scummvm_launcher_run() {
@@ -61,10 +43,11 @@ scummvm_exec_line() {
 	local application
 	application="$1"
 
-	local application_options
+	local application_options application_scummid
 	application_options=$(application_options "$application")
+	application_scummid=$(application_scummvm_scummid "$application")
 	cat <<- EOF
-	scummvm --path="\$PATH_GAME_DATA" $application_options "\$@" "\$SCUMMVM_ID"
+	scummvm --path="\$PATH_GAME_DATA" $application_options "\$@" "${application_scummid}"
 	EOF
 }
 
