@@ -106,7 +106,7 @@ archlinux_field_depend() {
 	local package
 	package="$1"
 
-	dependencies_archlinux_full_list "$package"
+	dependencies_full_list_packages "$package"
 }
 
 # Arch Linux - Print the value of the "provides" fields
