@@ -9,14 +9,11 @@ warning_debian_size_limit() {
 	case "$messages_language" in
 		('fr')
 			message='Le paquet suivant est trop gros pour le format .deb moderne : %s\n'
-			message="$message"'Merci de signaler cet avertissement sur notre système de suivi : %s\n\n'
 		;;
 		('en'|*)
 			message='The following package is too big for .deb modern format: %s\n'
-			message="$message"'Please report this warning on our issues tracker: %s\n\n'
 		;;
 	esac
 	print_message 'warning' "$message" \
-		"$package" \
-		"$PLAYIT_GAMES_BUG_TRACKER_URL"
+		"$package"
 }
