@@ -11,9 +11,6 @@ init_working_directory() {
 	local temporary_directory_path
 	temporary_directory_path=$(option_value 'tmpdir')
 
-	# Check that the given path is valid for temporary files storage
-	temporary_directory_checks "$temporary_directory_path"
-
 	# Generate a directory with a unique name for the current instance
 	local game_id
 	game_id=$(game_id)
@@ -25,3 +22,14 @@ init_working_directory() {
 	export PLAYIT_WORKDIR
 }
 
+# Check the validity of the temporary directory
+# USAGE: init_working_directory_checks
+init_working_directory_checks() {
+	# Get the path to the temporary directory
+	local temporary_directory_path
+	temporary_directory_path=$(option_value 'tmpdir')
+
+	# Check that the given path is valid for temporary files storage
+	temporary_directory_checks "$temporary_directory_path"
+}
+
