@@ -64,6 +64,8 @@ test_games_find_script_for_archive() {
 	game_script=$(games_find_script_for_archive 'another_game_archive.zip')
 	assertEquals "$game_script_expected" "$game_script"
 
+	local PLAYIT_ARCHIVES_PATH_BASE
+	PLAYIT_ARCHIVES_PATH_BASE="$TEST_TEMP_DIR"
 	SOURCE_ARCHIVE_NAME='some_game_archive.tar.gz'
 	SOURCE_ARCHIVE_PATH="${TEST_TEMP_DIR}/some_game_archive.tar.gz"
 	touch "$SOURCE_ARCHIVE_PATH"
