@@ -29,35 +29,6 @@ test_archives_path_base() {
 	assertEquals "$PWD" "$archives_path_base"
 }
 
-test_archives_integrity_check_md5() {
-	local PLAYIT_ARCHIVES_USED_LIST PLAYIT_WORKDIR ARCHIVE_BASE_0_MD5
-
-	PLAYIT_ARCHIVES_USED_LIST='ARCHIVE_BASE_0'
-	PLAYIT_WORKDIR="$TEST_TEMP_DIR"
-
-	mkdir --parents "${PLAYIT_WORKDIR}/cache"
-	cat >> "${PLAYIT_WORKDIR}/cache/hashes" <<- EOF
-	ARCHIVE_BASE_0 | e70187d92fa120771db99dfa81679cfc
-	EOF
-	ARCHIVE_BASE_0_MD5='e70187d92fa120771db99dfa81679cfc'
-	assertTrue 'archives_integrity_check_md5'
-	rm "${PLAYIT_WORKDIR}/cache/hashes"
-
-	mkdir --parents "${PLAYIT_WORKDIR}/cache"
-	cat >> "${PLAYIT_WORKDIR}/cache/hashes" <<- EOF
-	ARCHIVE_BASE_0 | 62298f00f1f2268c8d5004f5b2e9fc93
-	EOF
-	ARCHIVE_BASE_0_MD5='2ee16fab54493e1c2a69122fd2e56635'
-	assertFalse 'archives_integrity_check_md5'
-
-	mkdir --parents "${PLAYIT_WORKDIR}/cache"
-	cat >> "${PLAYIT_WORKDIR}/cache/hashes" <<- EOF
-	ARCHIVE_BASE_0 | eda90c314fd4d845ec9f3805b44de9f8
-	EOF
-	unset ARCHIVE_BASE_0_MD5
-	assertTrue 'A hashsum mismatch has been triggered for an archive that has no expected MD5 hash.' 'archives_integrity_check_md5'
-}
-
 test_archives_used_list() {
 	local archives_list archives_list_expected PLAYIT_ARCHIVES_USED_LIST
 
